@@ -1,4 +1,4 @@
-/* 
+/*
  * e-cell-float.h - Float item for e-table.
  * Copyright 2001, CodeFactory AB
  * Copyright 2001, Mikael Hallendal <micke@codefactory.se>
@@ -29,7 +29,7 @@
 
 #include <gal/e-table/e-cell-text.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_CELL_FLOAT_TYPE        (e_cell_float_get_type ())
 #define E_CELL_FLOAT(o)          (GTK_CHECK_CAST ((o), E_CELL_FLOAT_TYPE, ECellFloat))
@@ -48,6 +48,6 @@ typedef struct {
 GtkType    e_cell_float_get_type (void);
 ECell     *e_cell_float_new      (const char *fontname, GtkJustification justify);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_CELL_FLOAT_H_ */
