@@ -37,15 +37,13 @@
 #include "gal/widgets/e-canvas.h"
 #include "gal/widgets/e-canvas-utils.h"
 #include "gal/util/e-util.h"
-#include "gal/util/e-i18n.h"
-#include "gal/util/e-marshal.h"
 
 enum {
 	CURSOR_CHANGE,
 	LAST_SIGNAL
 };
 
-static guint etcta_signals [LAST_SIGNAL] = { 0 };
+static gint etcta_signals [LAST_SIGNAL] = { 0, };
 
 #define PARENT_OBJECT_TYPE gnome_canvas_group_get_type ()
 
@@ -54,20 +52,20 @@ static guint etcta_signals [LAST_SIGNAL] = { 0 };
 static GnomeCanvasGroupClass *etcta_parent_class;
 
 enum {
-	PROP_0,
-	PROP_HEADER,
-	PROP_MODEL,
-	PROP_MESSAGE,
-	PROP_WIDTH,
-	PROP_HEIGHT
+	ARG_0,
+	ARG_HEADER,
+	ARG_MODEL,
+	ARG_MESSAGE,
+	ARG_WIDTH,
+	ARG_HEIGHT,
 };
 
 static void
 etcta_cursor_change (GtkObject *object, gint row, gint col, ETableClickToAdd *etcta)
 {
-	g_signal_emit (etcta,
-		       etcta_signals [CURSOR_CHANGE], 0,
-		       row, col);
+	gtk_signal_emit (GTK_OBJECT (etcta),
+			 etcta_signals [CURSOR_CHANGE],
+			 row, col);
 }
 
 static void
@@ -75,7 +73,7 @@ etcta_add_table_header (ETableClickToAdd *etcta, ETableHeader *header)
 {
 	etcta->eth = header;
 	if (etcta->eth)
-		g_object_ref (etcta->eth);
+		gtk_object_ref (GTK_OBJECT (etcta->eth));
 	if (etcta->row)
 		gnome_canvas_item_set(GNOME_CANVAS_ITEM(etcta->row),
 				      "ETableHeader", header,
@@ -85,10 +83,14 @@ etcta_add_table_header (ETableClickToAdd *etcta, ETableHeader *header)
 static void
 etcta_drop_table_header (ETableClickToAdd *etcta)
 {
+	GtkObject *header;
+	
 	if (!etcta->eth)
 		return;
 
-	g_object_unref (etcta->eth);
+	header = GTK_OBJECT (etcta->eth);
+
+	gtk_object_unref (header);
 	etcta->eth = NULL;
 }
 
@@ -97,14 +99,14 @@ etcta_add_one (ETableClickToAdd *etcta, ETableModel *one)
 {
 	etcta->one = one;
 	if (etcta->one)
-		g_object_ref (etcta->one);
+		gtk_object_ref (GTK_OBJECT(etcta->one));
 	if (etcta->row)
 		gnome_canvas_item_set(GNOME_CANVAS_ITEM(etcta->row),
 				      "ETableModel", one,
 				      NULL);
-	g_object_set(etcta->selection,
-		     "model", one,
-		     NULL);
+	gtk_object_set(GTK_OBJECT(etcta->selection),
+		       "model", one,
+		       NULL);
 }
 
 static void
@@ -112,11 +114,11 @@ etcta_drop_one (ETableClickToAdd *etcta)
 {
 	if (!etcta->one)
 		return;
-	g_object_unref (etcta->one);
+	gtk_object_unref (GTK_OBJECT(etcta->one));
 	etcta->one = NULL;
-	g_object_set(etcta->selection,
-		     "model", NULL,
-		     NULL);
+	gtk_object_set(GTK_OBJECT(etcta->selection),
+		       "model", NULL,
+		       NULL);
 }
 
 static void
@@ -124,7 +126,7 @@ etcta_add_model (ETableClickToAdd *etcta, ETableModel *model)
 {
 	etcta->model = model;
 	if (etcta->model)
-		g_object_ref (etcta->model);
+		gtk_object_ref (GTK_OBJECT(etcta->model));
 }
 
 static void
@@ -133,7 +135,7 @@ etcta_drop_model (ETableClickToAdd *etcta)
 	etcta_drop_one (etcta);
 	if (!etcta->model)
 		return;
-	g_object_unref (etcta->model);
+	gtk_object_unref (GTK_OBJECT(etcta->model));
 	etcta->model = NULL;
 }
 
@@ -152,7 +154,7 @@ etcta_drop_message (ETableClickToAdd *etcta)
 
 
 static void
-etcta_dispose (GObject *object)
+etcta_destroy (GtkObject *object)
 {
 	ETableClickToAdd *etcta = E_TABLE_CLICK_TO_ADD (object);
 
@@ -160,37 +162,37 @@ etcta_dispose (GObject *object)
 	etcta_drop_model (etcta);
 	etcta_drop_message (etcta);
 	if (etcta->selection)
-		g_object_unref (etcta->selection);
+		gtk_object_unref (GTK_OBJECT(etcta->selection));
 	etcta->selection = NULL;
 
-	if (G_OBJECT_CLASS (etcta_parent_class)->dispose)
-		(*G_OBJECT_CLASS (etcta_parent_class)->dispose) (object);
+	if (GTK_OBJECT_CLASS (etcta_parent_class)->destroy)
+		(*GTK_OBJECT_CLASS (etcta_parent_class)->destroy) (object);
 }
 
 static void
-etcta_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+etcta_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 {
 	GnomeCanvasItem *item;
 	ETableClickToAdd *etcta;
 
-	item = GNOME_CANVAS_ITEM (object);
-	etcta = E_TABLE_CLICK_TO_ADD (object);
+	item = GNOME_CANVAS_ITEM (o);
+	etcta = E_TABLE_CLICK_TO_ADD (o);
 
-	switch (prop_id){
-	case PROP_HEADER:
+	switch (arg_id){
+	case ARG_HEADER:
 		etcta_drop_table_header (etcta);
-		etcta_add_table_header (etcta, E_TABLE_HEADER(g_value_get_object (value)));
+		etcta_add_table_header (etcta, E_TABLE_HEADER(GTK_VALUE_OBJECT (*arg)));
 		break;
-	case PROP_MODEL:
+	case ARG_MODEL:
 		etcta_drop_model (etcta);
-		etcta_add_model (etcta, E_TABLE_MODEL(g_value_get_object (value)));
+		etcta_add_model (etcta, E_TABLE_MODEL(GTK_VALUE_OBJECT (*arg)));
 		break;
-	case PROP_MESSAGE:
+	case ARG_MESSAGE:
 		etcta_drop_message (etcta);
-		etcta_add_message (etcta, (char*)g_value_get_string (value));
+		etcta_add_message (etcta, GTK_VALUE_STRING (*arg));
 		break;
-	case PROP_WIDTH:
-		etcta->width = g_value_get_double (value);
+	case ARG_WIDTH:
+		etcta->width = GTK_VALUE_DOUBLE (*arg);
 		if (etcta->row)
 			gnome_canvas_item_set(etcta->row,
 					      "minimum_width", etcta->width,
@@ -204,39 +206,35 @@ etcta_set_property (GObject *object, guint prop_id, const GValue *value, GParamS
 					      "x2", etcta->width - 1,
 					      NULL);
 		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		return;
-
 	}
 	gnome_canvas_item_request_update(item);
 }
 
 static void
-etcta_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+etcta_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 {
 	ETableClickToAdd *etcta;
 
-	etcta = E_TABLE_CLICK_TO_ADD (object);
+	etcta = E_TABLE_CLICK_TO_ADD (o);
 
-	switch (prop_id){
-	case PROP_HEADER:
-		g_value_set_object (value, etcta->eth);
+	switch (arg_id){
+	case ARG_HEADER:
+		GTK_VALUE_OBJECT (*arg) = GTK_OBJECT(etcta->eth);
 		break;
-	case PROP_MODEL:
-		g_value_set_object (value, etcta->model);
+	case ARG_MODEL:
+		GTK_VALUE_OBJECT (*arg) = GTK_OBJECT(etcta->model);
 		break;
-	case PROP_MESSAGE:
-		g_value_set_string (value, g_strdup(etcta->message));
+	case ARG_MESSAGE:
+		GTK_VALUE_STRING (*arg) = g_strdup(etcta->message);
 		break;
-	case PROP_WIDTH:
-		g_value_set_double (value, etcta->width);
+	case ARG_WIDTH:
+		GTK_VALUE_DOUBLE (*arg) = etcta->width;
 		break;
-	case PROP_HEIGHT:
-		g_value_set_double (value, etcta->height);
+	case ARG_HEIGHT:
+		GTK_VALUE_DOUBLE (*arg) = etcta->height;
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		arg->type = GTK_TYPE_INVALID;
 		break;
 	}
 }
@@ -306,15 +304,14 @@ finish_editing (ETableClickToAdd *etcta)
 	if (etcta->row) {
 		ETableModel *one;
 
-		e_table_item_leave_edit (E_TABLE_ITEM (etcta->row));
 		e_table_one_commit(E_TABLE_ONE(etcta->one));
 		etcta_drop_one (etcta);
-		gtk_object_destroy(etcta->row);
+		gtk_object_destroy(GTK_OBJECT(etcta->row));
 		etcta->row = NULL;
 
 		one = e_table_one_new(etcta->model);
 		etcta_add_one (etcta, one);
-		g_object_unref (one);
+		gtk_object_unref(GTK_OBJECT(one));
 
 		e_selection_model_clear(E_SELECTION_MODEL(etcta->selection));
 
@@ -323,14 +320,14 @@ finish_editing (ETableClickToAdd *etcta)
 						   "ETableHeader", etcta->eth,
 						   "ETableModel", etcta->one,
 						   "minimum_width", etcta->width,
-						   "horizontal_draw_grid", TRUE,
+						   "horizontal_draw_grid", FALSE,
 						   "vertical_draw_grid", TRUE,
 						   "selection_model", etcta->selection,
 						   "cursor_mode", E_CURSOR_SPREADSHEET,
 						   NULL);
 
-		g_signal_connect(etcta->row, "key_press",
-				 G_CALLBACK(item_key_press), etcta);
+		gtk_signal_connect(GTK_OBJECT(etcta->row), "key_press",
+				   GTK_SIGNAL_FUNC(item_key_press), etcta);
 
 		set_initial_selection (etcta);
 	}
@@ -343,15 +340,15 @@ static int
 etcta_event (GnomeCanvasItem *item, GdkEvent *e)
 {
 	ETableClickToAdd *etcta = E_TABLE_CLICK_TO_ADD (item);
-
+	
 	switch (e->type){
 	case GDK_BUTTON_PRESS:
 		if (etcta->text) {
-			gtk_object_destroy(etcta->text);
+			gtk_object_destroy(GTK_OBJECT(etcta->text));
 			etcta->text = NULL;
 		}
 		if (etcta->rect) {
-			gtk_object_destroy(etcta->rect);
+			gtk_object_destroy(GTK_OBJECT(etcta->rect));
 			etcta->rect = NULL;
 		}
 		if (!etcta->row) {
@@ -359,7 +356,7 @@ etcta_event (GnomeCanvasItem *item, GdkEvent *e)
 
 			one = e_table_one_new(etcta->model);
 			etcta_add_one (etcta, one);
-			g_object_unref (one);
+			gtk_object_unref(GTK_OBJECT(one));
 			
 			e_selection_model_clear(E_SELECTION_MODEL(etcta->selection));
 
@@ -368,14 +365,14 @@ etcta_event (GnomeCanvasItem *item, GdkEvent *e)
 							   "ETableHeader", etcta->eth,
 							   "ETableModel", etcta->one,
 							   "minimum_width", etcta->width,
-							   "horizontal_draw_grid", TRUE,
+							   "horizontal_draw_grid", FALSE,
 							   "vertical_draw_grid", TRUE,
 							   "selection_model", etcta->selection,
 							   "cursor_mode", E_CURSOR_SPREADSHEET,
 							   NULL);
 
-			g_signal_connect(etcta->row, "key_press",
-					 G_CALLBACK (item_key_press), etcta);
+			gtk_signal_connect(GTK_OBJECT(etcta->row), "key_press",
+					   GTK_SIGNAL_FUNC(item_key_press), etcta);
 
 			e_canvas_item_grab_focus (GNOME_CANVAS_ITEM(etcta->row), TRUE);
 
@@ -394,7 +391,6 @@ etcta_event (GnomeCanvasItem *item, GdkEvent *e)
 			return FALSE;
 			break;
 		}
-		break;
 			
 	default:
 		return FALSE;
@@ -410,21 +406,21 @@ etcta_reflow (GnomeCanvasItem *item, int flags)
 	double old_height = etcta->height;
 	
 	if (etcta->text) {
-		g_object_get(etcta->text,
-			     "height", &etcta->height,
-			     NULL);
+		gtk_object_get(GTK_OBJECT(etcta->text),
+			       "height", &etcta->height,
+			       NULL);
 		etcta->height += 6;
 	}
 	if (etcta->row) {
-		g_object_get(etcta->row,
-			     "height", &etcta->height,
-			     NULL);
+		gtk_object_get(GTK_OBJECT(etcta->row),
+			       "height", &etcta->height,
+			       NULL);
 	}
 
 	if (etcta->rect) {
-		g_object_set(etcta->rect,
-			     "y2", etcta->height - 1,
-			     NULL);
+		gtk_object_set(GTK_OBJECT(etcta->rect),
+			       "y2", etcta->height - 1,
+			       NULL);
 	}
 	if (old_height != etcta->height)
 		e_canvas_item_request_parent_reflow(item);
@@ -434,63 +430,40 @@ static void
 etcta_class_init (ETableClickToAddClass *klass)
 {
 	GnomeCanvasItemClass *item_class = GNOME_CANVAS_ITEM_CLASS(klass);
-	GObjectClass *object_class = G_OBJECT_CLASS(klass);
+	GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);
 
-	etcta_parent_class = g_type_class_ref (PARENT_OBJECT_TYPE);
+	etcta_parent_class = gtk_type_class (PARENT_OBJECT_TYPE);
 
 	klass->cursor_change = NULL;
 
-	object_class->dispose      = etcta_dispose;
-	object_class->set_property = etcta_set_property;
-	object_class->get_property = etcta_get_property;
+	object_class->destroy = etcta_destroy;
+	object_class->set_arg = etcta_set_arg;
+	object_class->get_arg = etcta_get_arg;
 
 	item_class->realize     = etcta_realize;
 	item_class->unrealize   = etcta_unrealize;
 	item_class->event       = etcta_event;
 
-	g_object_class_install_property (object_class, PROP_HEADER, 
-					 g_param_spec_object ("header",
-							      _("Header"),
-							      /*_( */"XXX blurb" /*)*/,
-							      E_TABLE_HEADER_TYPE,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_MODEL, 
-					 g_param_spec_object ("model",
-							      _("Model"),
-							      /*_( */"XXX blurb" /*)*/,
-							      E_TABLE_MODEL_TYPE,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_MESSAGE, 
-					 g_param_spec_string ("message",
-							      _("Message"),
-							      /*_( */"XXX blurb" /*)*/,
-							      NULL,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_WIDTH, 
-					 g_param_spec_double ("width",
-							      _("Width"),
-							      /*_( */"XXX blurb" /*)*/,
-							      0.0, G_MAXDOUBLE, 0.0,
-							      G_PARAM_READWRITE | G_PARAM_LAX_VALIDATION));
-
-	g_object_class_install_property (object_class, PROP_HEIGHT, 
-					 g_param_spec_double ("height",
-							      _("Height"),
-							      /*_( */"XXX blurb" /*)*/,
-							      0.0, G_MAXDOUBLE, 0.0,
-							      G_PARAM_READABLE | G_PARAM_LAX_VALIDATION));
+	gtk_object_add_arg_type ("ETableClickToAdd::header", GTK_TYPE_OBJECT,
+				 GTK_ARG_READWRITE, ARG_HEADER);
+	gtk_object_add_arg_type ("ETableClickToAdd::model", GTK_TYPE_OBJECT,
+				 GTK_ARG_READWRITE, ARG_MODEL);
+	gtk_object_add_arg_type ("ETableClickToAdd::message", GTK_TYPE_STRING,
+				 GTK_ARG_READWRITE, ARG_MESSAGE);
+	gtk_object_add_arg_type ("ETableClickToAdd::width", GTK_TYPE_DOUBLE,
+				 GTK_ARG_READWRITE, ARG_WIDTH);
+	gtk_object_add_arg_type ("ETableClickToAdd::height", GTK_TYPE_DOUBLE,
+				 GTK_ARG_READABLE, ARG_HEIGHT);
 
 	etcta_signals [CURSOR_CHANGE] =
-		g_signal_new ("cursor_change",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableClickToAddClass, cursor_change),
-			      NULL, NULL,
-			      e_marshal_VOID__INT_INT,
-			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
+		gtk_signal_new ("cursor_change",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableClickToAddClass, cursor_change),
+				gtk_marshal_NONE__INT_INT,
+				GTK_TYPE_NONE, 2, GTK_TYPE_INT, GTK_TYPE_INT);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, etcta_signals, LAST_SIGNAL);
 }
 
 static void
@@ -509,13 +482,34 @@ etcta_init (GnomeCanvasItem *item)
 	etcta->rect = NULL;
 
 	etcta->selection = e_table_selection_model_new();
-	g_signal_connect(etcta->selection, "cursor_changed",
-			 G_CALLBACK (etcta_cursor_change), etcta);
+	gtk_signal_connect(GTK_OBJECT(etcta->selection), "cursor_changed",
+			   GTK_SIGNAL_FUNC(etcta_cursor_change), etcta);
 
 	e_canvas_item_set_reflow_callback(item, etcta_reflow);
 }
 
-E_MAKE_TYPE(e_table_click_to_add, "ETableClickToAdd", ETableClickToAdd, etcta_class_init, etcta_init, PARENT_OBJECT_TYPE)
+GtkType
+e_table_click_to_add_get_type (void)
+{
+	static GtkType type = 0;
+
+	if (!type){
+		GtkTypeInfo info = {
+			"ETableClickToAdd",
+			sizeof (ETableClickToAdd),
+			sizeof (ETableClickToAddClass),
+			(GtkClassInitFunc) etcta_class_init,
+			(GtkObjectInitFunc) etcta_init,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		type = gtk_type_unique (PARENT_OBJECT_TYPE, &info);
+	}
+
+	return type;
+}
 
 
 /* The colors in this need to be themefied. */
@@ -532,7 +526,7 @@ e_table_click_to_add_commit (ETableClickToAdd *etcta)
 	if (etcta->row) {
 		e_table_one_commit(E_TABLE_ONE(etcta->one));
 		etcta_drop_one (etcta);
-		gtk_object_destroy(etcta->row);
+		gtk_object_destroy(GTK_OBJECT(etcta->row));
 		etcta->row = NULL;
 	}
 	if (!etcta->rect) {
