@@ -36,10 +36,10 @@
 G_BEGIN_DECLS
 
 #define E_TABLE_ITEM_TYPE        (e_table_item_get_type ())
-#define E_TABLE_ITEM(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TABLE_ITEM_TYPE, ETableItem))
-#define E_TABLE_ITEM_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TABLE_ITEM_TYPE, ETableItemClass))
-#define E_IS_TABLE_ITEM(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TABLE_ITEM_TYPE))
-#define E_IS_TABLE_ITEM_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TABLE_ITEM_TYPE))
+#define E_TABLE_ITEM(o)          (GTK_CHECK_CAST ((o), E_TABLE_ITEM_TYPE, ETableItem))
+#define E_TABLE_ITEM_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TABLE_ITEM_TYPE, ETableItemClass))
+#define E_IS_TABLE_ITEM(o)       (GTK_CHECK_TYPE ((o), E_TABLE_ITEM_TYPE))
+#define E_IS_TABLE_ITEM_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TABLE_ITEM_TYPE))
 
 typedef struct {
 	GnomeCanvasItem  parent;
@@ -75,8 +75,6 @@ typedef struct {
 	int              cursor_change_id;
 	int              cursor_activated_id;
 
-	guint            cursor_idle_id;
-
 	/* View row, -1 means unknown */
 	int              old_cursor_row;
 
@@ -115,7 +113,6 @@ typedef struct {
 	guint            gtk_grabbed : 1;
 
 	guint            queue_show_cursor : 1;
-	guint            grab_cancelled : 1;
 
 	int              frozen_count;
 
@@ -179,9 +176,8 @@ typedef struct {
 	gint        (*click)            (ETableItem *eti, int row, int col, GdkEvent *event);
 	gint        (*key_press)        (ETableItem *eti, int row, int col, GdkEvent *event);
 	gint        (*start_drag)       (ETableItem *eti, int row, int col, GdkEvent *event);
-	void        (*style_set)        (ETableItem *eti, GtkStyle *previous_style);
 } ETableItemClass;
-GType       e_table_item_get_type            (void);
+GtkType     e_table_item_get_type            (void);
 
 
 /*
