@@ -31,10 +31,10 @@
 G_BEGIN_DECLS
 
 #define E_TABLE_SCROLLED_TYPE        (e_table_scrolled_get_type ())
-#define E_TABLE_SCROLLED(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TABLE_SCROLLED_TYPE, ETableScrolled))
-#define E_TABLE_SCROLLED_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TABLE_SCROLLED_TYPE, ETableScrolledClass))
-#define E_IS_TABLE_SCROLLED(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TABLE_SCROLLED_TYPE))
-#define E_IS_TABLE_SCROLLED_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TABLE_SCROLLED_TYPE))
+#define E_TABLE_SCROLLED(o)          (GTK_CHECK_CAST ((o), E_TABLE_SCROLLED_TYPE, ETableScrolled))
+#define E_TABLE_SCROLLED_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TABLE_SCROLLED_TYPE, ETableScrolledClass))
+#define E_IS_TABLE_SCROLLED(o)       (GTK_CHECK_TYPE ((o), E_TABLE_SCROLLED_TYPE))
+#define E_IS_TABLE_SCROLLED_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TABLE_SCROLLED_TYPE))
 
 typedef struct {
 	EScrollFrame parent;
@@ -46,7 +46,7 @@ typedef struct {
 	EScrollFrameClass parent_class;
 } ETableScrolledClass;
 
-GType           e_table_scrolled_get_type                  (void);
+GtkType         e_table_scrolled_get_type                  (void);
 
 ETableScrolled *e_table_scrolled_construct                 (ETableScrolled *ets,
 							    ETableModel    *etm,
