@@ -38,11 +38,11 @@
 #include "gal/util/e-xml-utils.h"
 #include "e-tree-model.h"
 
-#define ETM_CLASS(e) (E_TREE_MODEL_GET_CLASS(e))
+#define ETM_CLASS(e) ((ETreeModelClass *)(GTK_OBJECT_GET_CLASS(e)))
 
-#define d(x)
+#define PARENT_TYPE (gtk_object_get_type())
 
-static GObjectClass *parent_class;
+static GtkObjectClass *parent_class;
 
 enum {
 	PRE_CHANGE,
@@ -53,7 +53,6 @@ enum {
 	NODE_INSERTED,
 	NODE_REMOVED,
 	NODE_DELETED,
-	NODE_REQUEST_COLLAPSE,
 	LAST_SIGNAL
 };
 
@@ -61,140 +60,129 @@ static guint e_tree_model_signals [LAST_SIGNAL] = {0, };
 
 
 static void
-e_tree_model_class_init (GObjectClass *klass)
+e_tree_model_class_init (GtkObjectClass *klass)
 {
 	ETreeModelClass *tree_class = (ETreeModelClass *) klass;
 
-	parent_class = g_type_class_peek_parent (klass);
+	parent_class = gtk_type_class (PARENT_TYPE);
 
 	e_tree_model_signals [PRE_CHANGE] =
-		g_signal_new ("pre_change",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, pre_change),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("pre_change",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, pre_change),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_tree_model_signals [NO_CHANGE] =
-		g_signal_new ("no_change",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, no_change),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("no_change",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, no_change),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_tree_model_signals [NODE_CHANGED] =
-		g_signal_new ("node_changed",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, node_changed),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
-			      G_TYPE_NONE, 1, G_TYPE_POINTER);
+		gtk_signal_new ("node_changed",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, node_changed),
+				gtk_marshal_NONE__POINTER,
+				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
 
 	e_tree_model_signals [NODE_DATA_CHANGED] =
-		g_signal_new ("node_data_changed",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, node_data_changed),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
-			      G_TYPE_NONE, 1, G_TYPE_POINTER);
+		gtk_signal_new ("node_data_changed",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, node_data_changed),
+				gtk_marshal_NONE__POINTER,
+				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
 
 	e_tree_model_signals [NODE_COL_CHANGED] =
-		g_signal_new ("node_col_changed",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, node_col_changed),
-			      (GSignalAccumulator) NULL, NULL,
-			      e_marshal_VOID__POINTER_INT,
-			      G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_INT);
+		gtk_signal_new ("node_col_changed",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, node_col_changed),
+				e_marshal_NONE__POINTER_INT,
+				GTK_TYPE_NONE, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
 
 	e_tree_model_signals [NODE_INSERTED] =
-		g_signal_new ("node_inserted",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, node_inserted),
-			      (GSignalAccumulator) NULL, NULL,
-			      e_marshal_VOID__POINTER_POINTER,
-			      G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_POINTER);
+		gtk_signal_new ("node_inserted",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, node_inserted),
+				e_marshal_NONE__POINTER_POINTER,
+				GTK_TYPE_NONE, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	e_tree_model_signals [NODE_REMOVED] =
-		g_signal_new ("node_removed",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, node_removed),
-			      (GSignalAccumulator) NULL, NULL,
-			      e_marshal_VOID__POINTER_POINTER_INT,
-			      G_TYPE_NONE, 3, G_TYPE_POINTER, G_TYPE_POINTER, G_TYPE_INT);
+		gtk_signal_new ("node_removed",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, node_removed),
+				e_marshal_NONE__POINTER_POINTER_INT,
+				GTK_TYPE_NONE, 3, GTK_TYPE_POINTER, GTK_TYPE_POINTER, GTK_TYPE_INT);
 
 	e_tree_model_signals [NODE_DELETED] =
-		g_signal_new ("node_deleted",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, node_deleted),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
-			      G_TYPE_NONE, 1, G_TYPE_POINTER);
+		gtk_signal_new ("node_deleted",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (klass),
+				GTK_SIGNAL_OFFSET (ETreeModelClass, node_deleted),
+				gtk_marshal_NONE__POINTER,
+				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
 
-	e_tree_model_signals [NODE_REQUEST_COLLAPSE] =
-		g_signal_new ("node_request_collapse",
-			      E_OBJECT_CLASS_TYPE (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeModelClass, node_request_collapse),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
-			      G_TYPE_NONE, 1, G_TYPE_POINTER);
+	E_OBJECT_CLASS_ADD_SIGNALS (klass, e_tree_model_signals, LAST_SIGNAL);
 
-	tree_class->get_root              = NULL;
+	tree_class->get_root             = NULL;
 
-	tree_class->get_parent            = NULL;
-	tree_class->get_first_child       = NULL;
-	tree_class->get_last_child        = NULL;
-	tree_class->get_next              = NULL;
-	tree_class->get_prev              = NULL;
+	tree_class->get_parent           = NULL;
+	tree_class->get_first_child      = NULL;
+	tree_class->get_last_child       = NULL;
+	tree_class->get_next             = NULL;
+	tree_class->get_prev             = NULL;
 
-	tree_class->is_root               = NULL;
-	tree_class->is_expandable         = NULL;
-	tree_class->get_children          = NULL;
-	tree_class->depth                 = NULL;
+	tree_class->is_root              = NULL;
+	tree_class->is_expandable        = NULL;
+	tree_class->get_children         = NULL;
+	tree_class->depth                = NULL;
 
-	tree_class->icon_at               = NULL;
+	tree_class->icon_at              = NULL;
 
-	tree_class->get_expanded_default  = NULL;
-	tree_class->column_count          = NULL;
+	tree_class->get_expanded_default = NULL;
+	tree_class->column_count         = NULL;
 
-	tree_class->has_save_id           = NULL;
-	tree_class->get_save_id           = NULL;
-	tree_class->has_get_node_by_id    = NULL;
-	tree_class->get_node_by_id        = NULL;
+	tree_class->has_save_id          = NULL;
+	tree_class->get_save_id          = NULL;
+	tree_class->has_get_node_by_id   = NULL;
+	tree_class->get_node_by_id       = NULL;
 
-	tree_class->has_change_pending    = NULL;
+	tree_class->has_change_pending   = NULL;
 
-	tree_class->value_at              = NULL;
-	tree_class->set_value_at          = NULL;
-	tree_class->is_editable           = NULL;
+	tree_class->value_at             = NULL;
+	tree_class->set_value_at         = NULL;
+	tree_class->is_editable          = NULL;
 
-	tree_class->duplicate_value       = NULL;
-	tree_class->free_value            = NULL;
-	tree_class->initialize_value      = NULL;
-	tree_class->value_is_empty        = NULL;
-	tree_class->value_to_string       = NULL;
+	tree_class->duplicate_value      = NULL;
+	tree_class->free_value           = NULL;
+	tree_class->initialize_value     = NULL;
+	tree_class->value_is_empty       = NULL;
+	tree_class->value_to_string      = NULL;
 
-	tree_class->pre_change            = NULL;
-	tree_class->no_change             = NULL;
-	tree_class->node_changed          = NULL;
-	tree_class->node_data_changed     = NULL;
-	tree_class->node_col_changed      = NULL;
-	tree_class->node_inserted         = NULL;
-	tree_class->node_removed          = NULL;
-	tree_class->node_deleted          = NULL;
-	tree_class->node_request_collapse = NULL;
+	tree_class->pre_change           = NULL;
+	tree_class->no_change            = NULL;
+	tree_class->node_changed         = NULL;
+	tree_class->node_data_changed    = NULL;
+	tree_class->node_col_changed     = NULL;
+	tree_class->node_inserted        = NULL;
+	tree_class->node_removed         = NULL;
+	tree_class->node_deleted         = NULL;
 }
 
-E_MAKE_TYPE(e_tree_model, "ETreeModel", ETreeModel, e_tree_model_class_init, NULL, G_TYPE_OBJECT)
+static void
+e_tree_init (GtkObject *object)
+{
+}
+
+E_MAKE_TYPE(e_tree_model, "ETreeModel", ETreeModel, e_tree_model_class_init, e_tree_init, PARENT_TYPE)
 
 
 /* signals */
@@ -214,9 +202,8 @@ e_tree_model_pre_change  (ETreeModel *tree_model)
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
 	
-	d(g_print("Emitting pre_change on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [PRE_CHANGE], 0);
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [PRE_CHANGE]);
 }
 
 /**
@@ -234,9 +221,8 @@ e_tree_model_no_change  (ETreeModel *tree_model)
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
 	
-	d(g_print("Emitting no_change on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NO_CHANGE], 0);
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [NO_CHANGE]);
 }
 
 /**
@@ -254,9 +240,8 @@ e_tree_model_node_changed  (ETreeModel *tree_model, ETreePath node)
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
 	
-	d(g_print("Emitting node_changed on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NODE_CHANGED], 0, node);
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [NODE_CHANGED], node);
 }
 
 /**
@@ -274,9 +259,8 @@ e_tree_model_node_data_changed  (ETreeModel *tree_model, ETreePath node)
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
 	
-	d(g_print("Emitting node_data_changed on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NODE_DATA_CHANGED], 0, node);
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [NODE_DATA_CHANGED], node);
 }
 
 /**
@@ -294,9 +278,8 @@ e_tree_model_node_col_changed  (ETreeModel *tree_model, ETreePath node, int col)
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
 	
-	d(g_print("Emitting node_col_changed on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NODE_COL_CHANGED], 0, node, col);
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [NODE_COL_CHANGED], node, col);
 }
 
 /**
@@ -315,10 +298,9 @@ e_tree_model_node_inserted (ETreeModel *tree_model,
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
 
-	d(g_print("Emitting node_inserted on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NODE_INSERTED], 0,
-		       parent_node, inserted_node);
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [NODE_INSERTED],
+			 parent_node, inserted_node);
 }
 
 /**
@@ -335,10 +317,9 @@ e_tree_model_node_removed  (ETreeModel *tree_model, ETreePath parent_node, ETree
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
 	
-	d(g_print("Emitting node_removed on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NODE_REMOVED], 0,
-		       parent_node, removed_node, old_position);
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [NODE_REMOVED],
+			 parent_node, removed_node, old_position);
 }
 
 /**
@@ -353,28 +334,10 @@ e_tree_model_node_deleted  (ETreeModel *tree_model, ETreePath deleted_node)
 {
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
-	
-	d(g_print("Emitting node_deleted on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NODE_DELETED], 0, deleted_node);
-}
-
-/**
- * e_tree_model_node_request_collapse:
- * @tree_model: 
- * @collapsed_node: 
- * 
- * 
- **/
-void
-e_tree_model_node_request_collapse  (ETreeModel *tree_model, ETreePath collapsed_node)
-{
-	g_return_if_fail (tree_model != NULL);
-	g_return_if_fail (E_IS_TREE_MODEL (tree_model));
-	
-	d(g_print("Emitting node_request_collapse on model 0x%p, a %s.\n", tree_model, gtk_type_name (GTK_OBJECT(tree_model)->klass->type)));
-
-	g_signal_emit (G_OBJECT (tree_model), e_tree_model_signals [NODE_REQUEST_COLLAPSE], 0, collapsed_node);
+
+	gtk_signal_emit (GTK_OBJECT (tree_model),
+			 e_tree_model_signals [NODE_DELETED],
+			 deleted_node);
 }
 
 
@@ -389,7 +352,11 @@ e_tree_model_node_request_collapse  (ETreeModel *tree_model, ETreePath collapsed
 ETreeModel *
 e_tree_model_new ()
 {
-	return (ETreeModel *) g_object_new (E_TREE_MODEL_TYPE, NULL);
+	ETreeModel *et;
+
+	et = gtk_type_new (e_tree_model_get_type ());
+
+	return et;
 }
 
 /**
@@ -549,7 +516,6 @@ gboolean
 e_tree_model_node_is_expandable (ETreeModel *etree, ETreePath node)
 {
 	g_return_val_if_fail(etree != NULL, FALSE);
-	g_return_val_if_fail(node != NULL, FALSE);
 
 	if (ETM_CLASS(etree)->is_expandable)
 		return ETM_CLASS(etree)->is_expandable(etree, node);
@@ -755,24 +721,14 @@ e_tree_model_has_change_pending (ETreeModel *etree)
 }
 
 /**
- * e_tree_model_value_at:
+ * e_tree_model_icon_of_node
  * @etree: The ETreeModel.
- * @node: The ETreePath to the node we're getting the data from.
- * @col: the column to retrieve data from
- * 
- * Return value: This function returns the value that is stored by the
- * @etree in column @col and node @node.  The data returned can be a
- * pointer or any data value that can be stored inside a pointer.
+ * @path: The ETreePath to the node we're getting the icon of.
  *
- * The data returned is typically used by an ECell renderer.
+ * XXX docs here.
  *
- * The data returned must be valid until the model sends a signal that
- * affect that piece of data.  node_changed and node_deleted affect
- * all data in tha t node and all nodes under that node.
- * node_data_changed affects the data in that node.  node_col_changed
- * affects the data in that node for that column.  node_inserted,
- * node_removed, and no_change don't affect any data in this way.
- **/
+ * return values: the GdkPixbuf associated with this node.
+ */
 void *
 e_tree_model_value_at (ETreeModel *etree, ETreePath node, int col)
 {
