@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-selection-model.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -27,7 +27,7 @@
 #include "e-selection-model.h"
 #include "gal/util/e-util.h"
 
-#define ESM_CLASS(e) ((ESelectionModelClass *)((GtkObject *)e)->klass)
+#define ESM_CLASS(e) ((ESelectionModelClass *)(GTK_OBJECT_GET_CLASS (e)))
 
 #define PARENT_TYPE gtk_object_get_type ()
 
@@ -47,7 +47,7 @@ enum {
 	ARG_0,
 	ARG_SORTER,
 	ARG_SELECTION_MODE,
-	ARG_CURSOR_MODE
+	ARG_CURSOR_MODE,
 };
 
 inline static void
@@ -92,11 +92,11 @@ esm_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 		break;
 
 	case ARG_SELECTION_MODE:
-		GTK_VALUE_ENUM(*arg) = esm->mode;
+		GTK_VALUE_INT(*arg) = esm->mode;
 		break;
 
 	case ARG_CURSOR_MODE:
-		GTK_VALUE_ENUM(*arg) = esm->cursor_mode;
+		GTK_VALUE_INT(*arg) = esm->cursor_mode;
 		break;
 	}
 }
@@ -113,7 +113,7 @@ esm_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 		break;
 
 	case ARG_SELECTION_MODE:
-		esm->mode = GTK_VALUE_ENUM(*arg);
+		esm->mode = GTK_VALUE_INT(*arg);
 		if (esm->mode == GTK_SELECTION_SINGLE) {
 			int cursor_row = e_selection_model_cursor_row(esm);
 			int cursor_col = e_selection_model_cursor_col(esm);
@@ -122,7 +122,7 @@ esm_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 		break;
 
 	case ARG_CURSOR_MODE:
-		esm->cursor_mode = GTK_VALUE_ENUM(*arg);
+		esm->cursor_mode = GTK_VALUE_INT(*arg);
 		break;
 	}
 }
@@ -180,42 +180,42 @@ e_selection_model_class_init (ESelectionModelClass *klass)
 				gtk_marshal_NONE__INT,
 				GTK_TYPE_NONE, 1, GTK_TYPE_INT);
 
-	klass->cursor_changed        = NULL;
-	klass->cursor_activated      = NULL;
-	klass->selection_changed     = NULL;
+	klass->cursor_changed     = NULL;
+	klass->cursor_activated   = NULL;
+	klass->selection_changed  = NULL;
 	klass->selection_row_changed = NULL;
 
-	klass->is_row_selected       = NULL;
-	klass->foreach               = NULL;
-	klass->clear                 = NULL;
-	klass->selected_count        = NULL;
-	klass->select_all            = NULL;
-	klass->invert_selection      = NULL;
-	klass->row_count             = NULL;
+	klass->is_row_selected    = NULL;
+	klass->foreach            = NULL;
+	klass->clear              = NULL;
+	klass->selected_count     = NULL;
+	klass->select_all         = NULL;
+	klass->invert_selection   = NULL;
+	klass->row_count          = NULL;
 
-	klass->change_one_row        = NULL;
-	klass->change_cursor         = NULL;
-	klass->cursor_row            = NULL;
-	klass->cursor_col            = NULL;
+	klass->change_one_row     = NULL;
+	klass->change_cursor      = NULL;
+	klass->cursor_row         = NULL;
+	klass->cursor_col         = NULL;
 
-	klass->select_single_row     = NULL;
-	klass->toggle_single_row     = NULL;
-	klass->move_selection_end    = NULL;
-	klass->set_selection_end     = NULL;
+	klass->select_single_row  = NULL;
+	klass->toggle_single_row  = NULL;
+	klass->move_selection_end = NULL;
+	klass->set_selection_end  = NULL;
 
 
 	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_selection_model_signals, LAST_SIGNAL);
 
 	gtk_object_add_arg_type ("ESelectionModel::sorter", GTK_TYPE_OBJECT,
 				 GTK_ARG_READWRITE, ARG_SORTER);
-	gtk_object_add_arg_type ("ESelectionModel::selection_mode", GTK_TYPE_ENUM,
+	gtk_object_add_arg_type ("ESelectionModel::selection_mode", GTK_TYPE_INT,
 				 GTK_ARG_READWRITE, ARG_SELECTION_MODE);
-	gtk_object_add_arg_type ("ESelectionModel::cursor_mode", GTK_TYPE_ENUM,
+	gtk_object_add_arg_type ("ESelectionModel::cursor_mode", GTK_TYPE_INT,
 				 GTK_ARG_READWRITE, ARG_CURSOR_MODE);
 }
 
 E_MAKE_TYPE(e_selection_model, "ESelectionModel", ESelectionModel,
-	    e_selection_model_class_init, e_selection_model_init, PARENT_TYPE)
+	    e_selection_model_class_init, e_selection_model_init, PARENT_TYPE);
 
 /** 
  * e_selection_model_is_row_selected
@@ -416,7 +416,6 @@ e_selection_model_do_something (ESelectionModel *selection,
 			break;
 		case GTK_SELECTION_BROWSE:
 		case GTK_SELECTION_MULTIPLE:
-		case GTK_SELECTION_EXTENDED:
 			if (shift_p) {
 				e_selection_model_set_selection_end (selection, row);
 			} else {
@@ -427,6 +426,9 @@ e_selection_model_do_something (ESelectionModel *selection,
 				}
 			}
 			break;
+		default:
+			g_assert_not_reached ();
+			break;
 		}
 		e_selection_model_change_cursor(selection, row, col);
 		gtk_signal_emit(GTK_OBJECT(selection),
@@ -506,7 +508,6 @@ e_selection_model_select_as_key_press (ESelectionModel *selection,
 	switch (selection->mode) {
 	case GTK_SELECTION_BROWSE:
 	case GTK_SELECTION_MULTIPLE:
-	case GTK_SELECTION_EXTENDED:
 		if (shift_p) {
 			e_selection_model_set_selection_end (selection, row);
 		} else if (!ctrl_p) {
@@ -517,6 +518,9 @@ e_selection_model_select_as_key_press (ESelectionModel *selection,
 	case GTK_SELECTION_SINGLE:
 		e_selection_model_select_single_row (selection, row);
 		break;
+	default:
+		g_assert_not_reached ();
+		break;
 	}
 	if (row != -1) {
 		e_selection_model_change_cursor(selection, row, col);
